Team
====

The `enough.community` maintainers team is always looking for new
members willing to help on a regular basis. If you feel like it,
:doc:`submit a merge request <contribute>`. After it is merged you
will be given credentials.

Contact
-------

The `contact mail <contact@enough.community>`__ alias is forwarded to:

* `Loïc Dachary <loic@dachary.org>`__
* `François Poulain <fpoulain@metrodore.fr>`__

Funding
-------

:doc:`funding`

* `Loïc Dachary <loic@dachary.org>`__

Infrastructure
--------------

:doc:`../services/bind`, :doc:`../community/infrastructure`

* `François Poulain <fpoulain@metrodore.fr>`__
* `Loïc Dachary <loic@dachary.org>`__
* `Pierre-Louis Bonicoli <pierre-louis.bonicoli@gmx.fr>`__

Weblate
-------

* `Loïc Dachary <loic@dachary.org>`__

Mattermost
----------

* `François Poulain <fpoulain@metrodore.fr>`__
* `Loïc Dachary <loic@dachary.org>`__
* `Pierre-Louis Bonicoli <pierre-louis.bonicoli@gmx.fr>`__

Readthedocs
-----------

The `readthedocs <https://readthedocs.org/>`__ user is `enough-community`.

* `Loïc Dachary <loic@dachary.org>`__
